summaryrefslogtreecommitdiff
path: root/shared-core/radeon_drm.h
diff options
context:
space:
mode:
authorJon Smirl <jonsmirl@yahoo.com>2005-08-04 13:59:48 +0000
committerJon Smirl <jonsmirl@yahoo.com>2005-08-04 13:59:48 +0000
commitbb9502ab01e7258c021f161b3caac8a508979dd8 (patch)
tree67eae2422486c7d80db3fadd19573a0b54d264c0 /shared-core/radeon_drm.h
parentea2c7a895d6456c83ee8489e1db7ae5a800f0abf (diff)
Mark some radeon init variables deprecated. These used to be passed in but
the driver already knew their correct value. For example the physical address of the framebuffer and registers.
Diffstat (limited to 'shared-core/radeon_drm.h')
-rw-r--r--shared-core/radeon_drm.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/shared-core/radeon_drm.h b/shared-core/radeon_drm.h
index 716e8e04..999cd611 100644
--- a/shared-core/radeon_drm.h
+++ b/shared-core/radeon_drm.h
@@ -492,7 +492,7 @@ typedef struct drm_radeon_init {
RADEON_INIT_R300_CP = 0x04
} func;
unsigned long sarea_priv_offset;
- int is_pci; /* not used, driver asks hardware */
+ int is_pci DEPRECATED; /* deprecated, driver asks hardware */
int cp_mode;
int gart_size;
int ring_size;
@@ -504,8 +504,8 @@ typedef struct drm_radeon_init {
unsigned int depth_bpp;
unsigned int depth_offset, depth_pitch;
- unsigned long fb_offset;
- unsigned long mmio_offset;
+ unsigned long fb_offset DEPRECATED; /* deprecated, driver asks hardware */
+ unsigned long mmio_offset DEPRECATED; /* deprecated, driver asks hardware */
unsigned long ring_offset;
unsigned long ring_rptr_offset;
unsigned long buffers_offset;